from setuptools import setup

setup(name='sumandmul',
    version='0.0.3',
    description='A package for summarizing array and multiplying the result on a number',
    url="https://github.com/brenscrazy/sumandmulitlyer",
    author='Vinnikov Gleb',
    author_email='glebmanufa@gmail.com',
    packages=['sumandmul'],
    install_requires=['numpy==1.19'
                      ]
    )
